function handleOpenURL(url) {
  console.log('called url scheme');
  console.log(url);
    window.localStorage.setItem("url_scheme", url);
}

angular.module('koClassified', [
  'ionic',

  // plugins
  'ngCordova',
  'jett.ionic.filter.bar',
  'ngLodash',
  'ngStorage',
  'ngAnimate',
  'ngTagsInput',
  'timer',
  'pascalprecht.translate',
  'ngMap',

  // constants
  'koClassified.constants',

  // filters and directives
  'koClassified.filters',
  'koClassified.directives.scrollWatch',
  'koClassified.directives.minWordsValidator',
  'koClassified.directives.equalsValidator',
  'koClassified.directives.goNative',
  'koClassified.directives.formatInput',

  // services and factories
  'koClassified.factories.adsFactory',
  'koClassified.factories.auth',
  'koClassified.factories.pages',
  'koClassified.factories.payment',
  'koClassified.factories.blog',
  'koClassified.services.auth',
  'koClassified.services.adsService',
  'koClassified.services.modalService',
  'koClassified.services.imageService',
  'koClassified.services.uploadQueueService',
  'koClassified.services.doubleTapExitService',
  'koClassified.services.connectivityMonitor',
  'koClassified.services.navigation',
  'koClassified.services.payment',
  'koClassified.services.notification',
  'koClassified.services.GooglePlaces',
  'koClassified.services.blog',

  // controllers
  'koClassified.controllers.listItems',
  'koClassified.controllers.addAds',
  'koClassified.controllers.auth',
  'koClassified.controllers.menu',
  'koClassified.controllers.pages',
  'koClassified.controllers.payment',
  'koClassified.controllers.editAds',
    'koClassified.controllers.blog'
])

.run(function($ionicPlatform, $state, $rootScope) {

    $ionicPlatform.ready(function() {
      // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
      // for form inputs)
      if (window.cordova && window.cordova.plugins.Keyboard) {
        cordova.plugins.Keyboard.hideKeyboardAccessoryBar(true);
        cordova.plugins.Keyboard.disableScroll(true);

      }


      if (window.StatusBar) {
        // org.apache.cordova.statusbar required
        StatusBar.styleDefault();
        if (ionic.Platform.isAndroid()) {
            // blue(positive) #0288d1
            // green(balanced) #28a54c
            // assertive(red) #ef473a
                StatusBar.styleLightContent(true);
                StatusBar.backgroundColorByHexString("#0288d1");
        }
      }

      window.plugins.nativepagetransitions.globalOptions.duration = 400;
      window.plugins.nativepagetransitions.globalOptions.iosdelay = 350;
      window.plugins.nativepagetransitions.globalOptions.androiddelay = 300;
      window.plugins.nativepagetransitions.globalOptions.winphonedelay = 350;
      window.plugins.nativepagetransitions.globalOptions.slowdownfactor = 4;
      // these are used for slide left/right only currently
      window.plugins.nativepagetransitions.globalOptions.fixedPixelsTop = 0;
      window.plugins.nativepagetransitions.globalOptions.fixedPixelsBottom = 0;
  });
})

.config(function($stateProvider, $urlRouterProvider, $ionicFilterBarConfigProvider, $ionicConfigProvider, $translateProvider) {

    $ionicFilterBarConfigProvider.setPlatformConfig('default', {
        placeholder: 'به دنبال چه هستید؟'
    });
    $ionicConfigProvider.backButton.text("");

    for(lang in translations){
        $translateProvider.translations(lang, translations[lang]);
    }

    $translateProvider.preferredLanguage('fa');
    $translateProvider.useSanitizeValueStrategy('sce');
    $stateProvider
      .state('app', {
          url: "/app",
          abstract: true,
          templateUrl: "templates/menu.html",
          controller: 'menuController'
      })

      .state('app.list', {
          url: "/list",
          views: {
            'menuContent': {
              templateUrl: "templates/list.html",
              controller : "listController"
            }
          }
      })

      .state('app.detail', {
          url : "/detail/:id",
          views : {
            'menuContent' : {
                templateUrl : "templates/detail.html",
                controller : "detailsController"
            }
          }
      })

      .state('app.add-ads', {
        url : "/add-ads",
        views : {
            'menuContent' : {
                templateUrl : "templates/add_ads.html",
                controller : "addAdsController"
            }
        }
      })

      .state('app.favourites', {
          url: "/favourites",
          views: {
              'menuContent': {
                  templateUrl: 'templates/favourites.html',
                  controller: "favouritesController"
              }
          }
      })

      .state('app.profile', {
          url: '/profile',
          views: {
              'menuContent': {
                  templateUrl: 'templates/profile.html',
                  controller: "profileController"
              }
          }
      })

      .state('app.change-password', {
          url: '/change-password',
          views: {
              'menuContent': {
                  templateUrl: 'templates/change_password.html',
                  controller: "passwordController"
              }
          }
      })

      .state('app.my-ads', {
          url: '/profile/my-ads',
          views: {
              'menuContent': {
                  templateUrl: 'templates/my_ads.html',
                  controller: "myAdsController"
              }
          }
      })

      .state('app.rules', {
          url: '/profile/rules',
          views: {
              'menuContent': {
                  templateUrl: 'templates/rules.html',
                  controller: "pagesController"
              }
          }
      })

      .state('app.contact', {
        url: '/contact-us',
        views: {
          'menuContent': {
            templateUrl: 'templates/contact.html',
            controller: "contactController"
          }
        }
      })

      .state('app.notification', {
          url : "/notification/:id",
          views : {
              'menuContent' : {
                  templateUrl : "templates/notification.html",
                  controller : "notificationController"
              }
          }
      })

      .state('app.edit', {
        url : "/item/:id/edit",
        views : {
          'menuContent' : {
            templateUrl : "templates/edit_ads.html",
            controller : "editAdsController"
          }
        }
      })

      .state('app.pricing', {
          url : "/pricing",
          views : {
              'menuContent' : {
              templateUrl : "templates/pricing.html",
              controller : "pricingController"
            }
          }
      })

      .state('app.auth', {
          url: "/auth",
          views: {
              'menuContent': {
                  templateUrl: 'templates/auth.html',
                  controller: "authController"
              }
          }
      })

      .state('app.auth_password', {
          url : "/auth/password",
          views : {
            'menuContent' : {
              templateUrl : "templates/auth_password.html",
              controller : "authController"
            }
          }
      })

      .state('app.auth_forgot', {
          url : "/auth/forgot",
          views : {
            'menuContent' : {
              templateUrl : "templates/auth_forgot.html",
              controller : "authForgotController"
            }
          }
      })

      .state('app.auth_forgot_verify', {
          url : "/auth/forgot/verify",
          views : {
              'menuContent' : {
                  templateUrl : "templates/auth_forgot_verify.html",
                  controller : "authForgotController"
              }
          }
      })

      .state('app.auth_forgot_reset', {
          url : "/auth/forgot/reset",
          views : {
              'menuContent' : {
                  templateUrl : "templates/auth_forgot_reset_password.html",
                  controller  : "authForgotController"
              }
          }
      })

      .state('app.blog', {
            url : "/blog",
            views : {
                'menuContent' : {
                    templateUrl : "templates/blog.html",
                    controller  : "blogController"
                }
            }
      })

      .state('app.blog_detail', {
            url : "/blog/detail/:id",
            views : {
                'menuContent' : {
                    templateUrl : "templates/blog_detail.html",
                    controller  : "blogDetailController"
                }
            }
      });

      // if none of the above states are matched, use this as the fallback
      $urlRouterProvider.otherwise('/app/list');
});
