angular.module('koClassified.controllers.auth', [])

.controller('authController', ['$scope', '$rootScope', '$cordovaToast', 'navigationService', 'authService', 'adsService',
                      function( $scope,   $rootScope,   $cordovaToast,   navigationService,   authService,   adsService)
{
    $scope.$on('$ionicView.beforeEnter', function() {
        if(authService.isLoggedIn()) {
            // TODO ::
        }
        if( ! authService.passwordPageAction ) {
            // TODO ::
        }
    });


    $scope.authService = authService;

    adsService.loadSettings().then(function() {
        $scope.usernameTitle = adsService.usernameTitle();
    });

    $scope.authFormData = {};
    $scope.passwordFormData = {};

    $scope.isSending = false;
    $scope.canResend = false;
    $scope.isResending = false;

    /**
     * Function to be called when clicked on login_or_register
     */
    $scope.loginOrRegister = function(form) {

        if($scope.isSending) {
            return false;
        }

        $scope.form = form;
        $scope.submitted = true;
        if(form.$invalid) {
            $cordovaToast.showShortBottom('اطلاعات وارد شده صحیح نمی باشد');
            return false;
        }

        $scope.isSending = true;
        authService.loginOrRegister($scope.authFormData).then(function(response) {
            $scope.isSending = false;
            $scope.authType = 'login';

            if(response.status) {
                authService.triedUsername = response.register_param;
                authService.passwordPageAction = response.action;
                if(response.action === 'activation') {
                    authService.activationMethod = response.method;
                    authService.activationResendTime = response.resend_time;
                }
                navigationService.go('app.auth_password');
            } else {
                $cordovaToast.showShortBottom(response.errors);
            }
        });
    };

    /**
     * Function to be called when clicked on submit password
     */
    $scope.submitPassword = function(form) {
        if($scope.isSending) {
            return false;
        }

        $scope.form = form;
        $scope.submitted = true;
        if(form.$invalid) {
            $cordovaToast.showShortBottom('اطلاعات وارد شده صحیح نمی باشد');
            return false;
        }

        $scope.passwordFormData.username = authService.getTriedUsername();

        if(authService.passwordPageAction === 'login') {
            login();
        }
        if(authService.passwordPageAction === 'set-password') {
            register();
        }
        if(authService.passwordPageAction === 'activation') {
            checkActivationCode();
        }
    };

    /**
     * ReSends activation code
     */
    $scope.resendActivationCode = function() {
        if($scope.isSending) {
            return false;
        }
        $scope.isResending = true;

        $scope.passwordFormData.username = authService.getTriedUsername();
        authService.resendActivationCode($scope.passwordFormData).then(function(response) {
            $scope.canResend = false;
            $scope.isResending = false;
            $cordovaToast.showShortBottom(response.message);
            authService.activationResendTime = response.resend_time;
        }, function(error) {
            $scope.isResending = false;
            $cordovaToast.showShortBottom(error.message);
        });
    };

    /**
     * Function to be called after finishing resend timer
     */
    $scope.resendTimerFinished = function() {
        authService.activationResendTime = 0;
        $scope.canResend = true;
    };

    /**
     *  Handles sending data for login
     */
    var login = function() {
        $scope.isSending = true;

        authService.login($scope.passwordFormData).then( function(response) {

            passwordSuccessCallback();

        }, function(error) {
            $scope.isSending = false;
            if(error.code === 'not-found') {
                deport();
            } else {
                $cordovaToast.showShortBottom(error.message);
            }
        });
    };

    /**
     * Handles sending data for register
     */
    var register = function() {
        $scope.isSending = true;

        authService.register($scope.passwordFormData).then( function(response) {

            passwordSuccessCallback();

        }, function(error) {
            if(error.code === 'already-registered') {
                deport();
            } else {
                $cordovaToast.showShortBottom(error.message);
            }
        });
    };

    /**
     * Handles checking activation code
     */
    var checkActivationCode = function() {
        $scope.isSending = true;

        authService.checkActivationCode($scope.passwordFormData).then( function(response) {

            passwordSuccessCallback();
        }, function(error) {
            $scope.isSending = false;
            $cordovaToast.showShortBottom(error.message);
        });
    };

    /**
     * Function to be called after successful password request
     */
    var passwordSuccessCallback = function() {
        $scope.isSending = false;

        if(authService.isSubmitAuth()) {
            $rootScope.$emit("submitAdsForm", {});
            navigationService.go('app.add-ads');
        }

        if(authService.isNormalAuth()) {
            $cordovaToast.showShortBottom('ورود با موفقیت انجام شد');
            navigationService.go('app.profile');
        }
    };

    /**
     *  sends user back to username page
     */
    var deport = function() {
        authService.passwordPageAction = null;
        navigationService.go('app.auth');
    };

}])


/*----------------------------------------------------------------------------------***
 |
 |                              auth Forgot Controller
 |
 ***---------------------------------------------------------------------------------***/
.controller('authForgotController', ['$scope', '$rootScope', '$cordovaToast', '$state', 'navigationService', 'authService', 'adsService',
                            function( $scope,   $rootScope,   $cordovaToast,   $state,   navigationService,   authService,   adsService)
{
    $scope.$on('$ionicView.beforeEnter', function() {
        if(authService.isLoggedIn()) {
            navigationService.go('app.list');
        }
        var current_state = $state.current.name;
        if(current_state === 'app.auth_forgot_verify' && ! authService.triedUsername) {
            navigationService.go("app.auth_forgot");
        }
        if(current_state === 'app.auth_forgot_reset' && ! authService.temporaryToken) {
            navigationService.go("app.auth_forgot_verify");
        }
    });

    $scope.authService = authService;

    adsService.loadSettings().then(function() {
        $scope.usernameTitle = adsService.usernameTitle(true);
    });

    $scope.forgotFormData = {};
    $scope.verifyFormData = {};
    $scope.passwordFormData = {};

    $scope.isSending = false;
    $scope.canResend = false;
    $scope.isResending = false;

    /**
     * Function to be called when clicked on login_or_register
     */
    $scope.checkForgotParam = function(form) {

        if($scope.isSending) {
            return false;
        }

        $scope.form = form;
        $scope.submitted = true;
        if(form.$invalid) {
            $cordovaToast.showShortBottom('اطلاعات وارد شده صحیح نمی باشد');
            return false;
        }

        $scope.isSending = true;
        authService.checkForgotParam($scope.forgotFormData).then(function(response) {
            $scope.isSending = false;

            if(response.status) {
                authService.triedUsername = response.forgot_param;
                authService.activationMethod = response.method;
                $cordovaToast.showShortBottom(response.message);
                navigationService.go('app.auth_forgot_verify');
            } else {
                $cordovaToast.showShortBottom(response.errors);
            }
        }, function() {
            $cordovaToast.showShortBottom('مشکلی در اجرای عملیات پیش آمده است');
        });

    };

    /**
     * Function to be called when clicked on submit password
     */
    $scope.verifyCode = function(form) {
        if($scope.isSending) {
          return false;
        }

        $scope.form = form;
        $scope.submitted = true;
        if(form.$invalid) {
            $cordovaToast.showShortBottom('اطلاعات وارد شده صحیح نمی باشد');
            return false;
        }

        $scope.verifyFormData.username = authService.getTriedUsername();

        $scope.isSending = true;
        authService.checkForgotVerificationCode($scope.verifyFormData).then( function(response) {
            $scope.isSending = false;
            authService.triedUsername = null;
            authService.temporaryToken = response.token;
            $cordovaToast.showShortBottom('تایید با موفقیت انجام شد');
            navigationService.go("app.auth_forgot_reset");
        }, function(error) {
            $scope.isSending = false;
            $cordovaToast.showShortBottom(error.message);
        });
    };

    /*
     * Handles the form submission for change password
     */
    $scope.resetPassword = function(form)  {
        $scope.submitted = true;
        $scope.form = form;
        if(form.$invalid || $scope.isLoading) {
            return false;
        }

        $scope.isLoading = true;
        var data = {
            password: $scope.passwordFormData.password,
            token:    authService.temporaryToken
        };

        authService.resetForgottenPassword(data).then(function() {
            $scope.isLoading = false;
            authService.temporaryToken = null;
            authService.triedUsername = null;

            $cordovaToast.showShortBottom('رمزعبور با موفقیت تغییر یافت');
            navigationService.go('app.profile');
        }, function(errors) {
            $scope.isLoading = false;
            $cordovaToast.showShortBottom(errors);
        });
    };

}])


/*----------------------------------------------------------------------------------***
|
|                              Profile Controller
|
***---------------------------------------------------------------------------------***/
.controller('profileController', ['$scope', 'navigationService', 'authService', 'adsService', function($scope, navigationService, authService, adsService) {

    $scope.$on('$ionicView.beforeEnter', function() {
        if(!authService.isLoggedIn()) {
            navigationService.go('app.list');
        }

        $scope.isLoading = true;
        $scope.authService.adsCount().then(function(result) {
            $scope.isLoading = false;
            $scope.adsCount = result.ads_count;
        });
    });


    $scope.authService = authService;
    $scope.adsService  = adsService;



    $scope.logout = function() {
        authService.logout();
        navigationService.go('app.list');
    };

}])


/*----------------------------------------------------------------------------------***
|
|                              My Ads Controller
|
***---------------------------------------------------------------------------------***/
.controller('myAdsController', ['$scope', '$ionicPopup', '$rootScope', '$ionicActionSheet', '$timeout', 'modalService', 'navigationService', 'authService', 'adsService', 'paymentService',
                       function($scope,    $ionicPopup,   $rootScope,   $ionicActionSheet, $timeout,    modalService,   navigationService,   authService,   adsService,   paymentService) {

      $scope.$on('$ionicView.beforeEnter', function() {
          if ( ! authService.isLoggedIn() ) {
              navigationService.go('app.list');
          }
          $scope.random_number = Math.random();
          $scope.modals = modalService.init($scope);

          $scope.isLoading = true;
          adsService.allAdsOfUser(authService.token).then(function(result) {
            $scope.adss = result.adss;
            $scope.isLoading = false;
          }, function() {
            $scope.isLoading = false;
          });
      });

      $scope.adss = null;
      $scope.adsService = adsService;
      $scope.is_creating = false;

      $scope.canAddSpecialItem = true;
      adsService.loadSettings().then(function(settings) {
          if(settings.APP_CAN_ADD_SPECIAL_ADS !== 'YES') {
              $scope.canAddSpecialItem = false;
          }
      });

      $scope.showActionSheet = function(item) {
          var buttons = [];
          if(adsService.isEditable(item)) {
              buttons.push({ text: '<i class="icon ion-edit"></i>ویرایش', action: function() {
                  navigationService.go("app.edit", {id: item.ID});
              }});
          }
          if(adsService.isWaitingForPayment(item) && $scope.canAddSpecialItem) {
              buttons.push({ text: '<i class="icon ion-bag"></i>پرداخت', action: function() {
                  $scope.goToPayment(item);
              }});
          }
          if (adsService.isShown(item)) {
              buttons.push({ text: '<i class="icon ion-clock"></i>جهش', action: function() {
                  $scope.mutationClicked(item);
              }});
          }
          if(adsService.isEditable(item) && $scope.canAddSpecialItem) {
              buttons.push({ text: '<i class="icon ion-ios-color-wand"></i>تغییر پلان ویژه', action: function() {
                  $scope.changePlan(item);
              }});
          }
          buttons.push({ text: '<i class="icon ion-ios-trash-outline"></i>حذف', action: function() {
              $scope.showDeleteItemPopup(item);
          }});
          buttons.push({ text: '<i class="icon ion-ios-close-empty"></i>بی خیال'});

          $ionicActionSheet.show({
              buttons: buttons,
              buttonClicked: function(index) {
                  if(buttons[index].action) {
                      buttons[index].action();
                  }
                  return true;
              }
          });
      };

      $scope.mutationClicked = function(item) {
          $scope.mutationLeft = adsService.mutationsLeftCount(item);
          $scope.itemToMutate = item;

          var cssClass = 'no-header-popup loading-popup rejection-popup ' + $scope.main_theme + ''; //main_theme comes from rootScope
          $scope.mutateItemPopup = $ionicPopup.show({
              templateUrl : 'templates/popups/mutation_popup.html',
              scope : $scope,
              cssClass : cssClass
          });
      };

       /**
        * Applies Mutation
        *
        * @param item
        */
      $scope.mutateItem = function(item) {
          $scope.isMutating = true;

          var data = {
              id: item.ID,
              user_token: authService.token
          };
          adsService.mutate(data).then(function(result) {
              $scope.isMutating = false;
              $scope.mutationEnded = true;

              if (result.status) {
                  $scope.mutationSuccess = true;
              } else {
                  $scope.mutationError = true;
              }
          });
      };

      $scope.reloadPage = function() {
          $scope.mutateItemPopup.close();

          adsService.resetMyAds();
          $scope.isLoading = true;
          adsService.allAdsOfUser(authService.token).then(function(result) {
              $scope.adss = result.adss;
              $scope.isLoading = false;
              $scope.isMutating = false;
              $scope.mutationEnded = false;
              $scope.mutationSuccess = false;
              $scope.mutationError = false;
          }, function() {
              $scope.isLoading = false;
          });
      };

     /**
      * Shows popup for deleting an item
      * @param item
      */
       $scope.showDeleteItemPopup = function(item) {
           var cssClass = 'no-header-popup loading-popup rejection-popup ' + $scope.main_theme + ''; //main_theme comes from rootScope
           $scope.deleteItemPopup = $ionicPopup.show({
               templateUrl : 'templates/popups/delete_item.html',
               scope : $scope,
               cssClass : cssClass,
               buttons: [
                  {
                       text: '<b>بله</b>',
                       type: 'button-balanced',
                       onTap: function() {
                           adsService.deleteItem(item, authService.token);
                           _.remove($scope.adss, {ID: item.ID});
                           $scope.deleteItemPopup.close();
                       }
                  },
                  {
                     text: '<b>خیر</b>',
                     type: 'button-assertive',
                     onTap: function() {
                       $scope.deleteItemPopup.close();
                     }
                  }
               ]
           });
       };

      $scope.showRejectionCause = function(item) {
          $scope.rejectionCause = item.REJECTION_CAUSE;
          var cssClass = 'no-header-popup loading-popup rejection-popup ' + $scope.main_theme + ''; //main_theme comes from rootScope
          $scope.rejectionCausePopup = $ionicPopup.show({
              templateUrl : 'templates/popups/rejection_cause.html',
              scope : $scope,
              cssClass : cssClass,
              buttons: [
                {
                  text: '<b>متوجه شدم</b>',
                  type: 'button-energized',
                  onTap: function() {
                      $scope.rejectionCausePopup.close();
                      $scope.goBack();
                  }
                }
              ]
          });
      };

      $scope.changePlanPopup = function(plan) {
          $scope.change_plan_popup_text = 'هزینه تغییر به پلان ویژه ' + plan.PLAN_TITLE + ' : <br>' + plan.PLAN_PRICE + ' تومان <br>';
          $scope.ChangePlanPopup = $ionicPopup.show({
              templateUrl: 'templates/popups/change_plan_confirm.html',
              cssClass: 'no-header-popup loading-popup',
              scope: $scope
          });
      };

      $scope.closeChangePlanPopup = function() {
          $scope.ChangePlanPopup.close();
      };

      $scope.changePlan = function(item) {
          $scope.changePlanAds = item;
          $rootScope.showModal('plans', {type: 'no-free-plan', current_plan_id: item.special.plan.ID});
      };

      $scope.setPlan = function(plan) {
          $scope.newPlan = plan;
          $timeout(function(){
                $scope.changePlanPopup(plan);
          }, 400);
      };

      $scope.payForChangePlan = function() {
          $scope.closeChangePlanPopup();
          $scope.goToPayment($scope.changePlanAds, true, $scope.newPlan);
      };

      $scope.goToPayment = function(adsItem, isChangePlan, new_plan) {
          isChangePlan = isChangePlan || false;

          if( ! $scope.adsService.isWaitingForPayment(adsItem) && ! isChangePlan ) {
              return false;
          }

          $scope.loading_text = 'در حال اتصال به درگاه پرداخت';
          $scope.loadingPopup = $ionicPopup.show({
              templateUrl: 'templates/popups/adding_ads.html',
              cssClass: 'no-header-popup loading-popup',
              scope: $scope
          });

          paymentService.setScope($scope);

          var price = adsItem.special.plan.PLAN_PRICE;
          var payment_type = 'add-new';
          var new_plan_id = 0;
          if(isChangePlan) {
              price = new_plan.PLAN_PRICE;
              payment_type = 'change-plan';
              new_plan_id = new_plan.ID;
          }

          // TODO :: use token for user_id (currently 1)
          paymentService.start(adsItem.ID, adsItem.special.ID, null, price, adsItem.ADS_OWNER_EMAIL, adsItem.ADS_OWNER_PHONE, payment_type, new_plan_id).then(
              function() {
                // success
              }, function() {
                  $scope.loadingPopup.close();
              }
          );

          $scope.paymentSuccessCallback = function() {

              $scope.payment_data = paymentService.payment_data;
              $scope.loadingPopup.close();

              var successPaymentPopup = $ionicPopup.show({
                templateUrl: 'templates/popups/success_payment_popup.html',
                cssClass: 'no-header-popup loading-popup success-payment-popup',
                scope: $scope,
                buttons: [{
                    text: '<b>متوجه شدم</b>',
                    type: 'button-energized',
                    onTap: function() {
                        adsService.resetMyAds();
                        $scope.isLoading = true;
                        adsService.allAdsOfUser(authService.token).then(function(result) {
                          $scope.adss = result.adss;
                          $scope.isLoading = false;
                        }, function() {
                          $scope.isLoading = false;
                        });
                        successPaymentPopup.close();
                    }
                }]
              });
          };

          $scope.paymentErrorCallback = function() {
              $scope.payment_data = paymentService.payment_data;
              $scope.loadingPopup.close();
              var failedPaymentPopup = $ionicPopup.show({
                  templateUrl: 'templates/popups/failed_payment_popup.html',
                  cssClass: 'no-header-popup loading-popup failed-payment-popup',
                  scope: $scope,
                  buttons: [{
                      text: '<b>متوجه شدم</b>',
                      type: 'button-energized',
                      onTap: function() {
                          failedPaymentPopup.close();
                      }
                  }]
              });
          };
      };
}])

/*----------------------------------------------------------------------------------***
 |
 |                              Change Password Controller
 |
 ***---------------------------------------------------------------------------------***/

.controller('passwordController', ['$scope', '$cordovaToast', 'navigationService', 'authService', function($scope, $cordovaToast, navigationService, authService) {

    $scope.$on('$ionicView.beforeEnter', function() {
        if(!authService.isLoggedIn()) {
            navigationService.go('app.list');
        }

        $scope.formData  = {};
        $scope.submitted = false;
    });

    $scope.vm = { passwordForm: null };
    $scope.formData = {};
    $scope.isLoading = false;


    /*
    * Handles the form submission for change password
    */
    $scope.changePassword = function()  {

        $scope.submitted = true;
        var form = $scope.vm.passwordForm;
        if(form.$invalid || $scope.isLoading) {
            return false;
        }

        $scope.isLoading = true;
        var data = {
            old_password: $scope.formData.oldPassword,
            password: $scope.formData.password
        };

        authService.changePassword(data).then(function() {
            $scope.isLoading = false;
            $cordovaToast.showShortBottom('رمزعبور با موفقیت تغییر یافت');
        }, function(errors) {
            $scope.isLoading = false;
            $cordovaToast.showShortBottom(errors);
        });
    };

    $scope.goBack = function() {
        navigationService.go('app.profile');
    };
}]);