angular.module('koClassified.controllers.listItems', [])

    /*----------------------------------------------------------------------------------***
     |
     |                         Ads List Controller
     |
     ***--------------------------------------------------------------------------------***/
    .controller('listController', ['$scope', '$ionicFilterBar', '$cordovaInAppBrowser', 'notificationService', '$localStorage', '$state', '$ionicPopover', '$cordovaSocialSharing', 'APP_OPTIONS', 'adsService', 'modalService', 'connectivityMonitor', '$ionicPopup', '$ionicPlatform', '$cordovaToast', '$timeout', '$ionicHistory', 'navigationService', '$rootScope', 'authService',
                           function($scope,   $ionicFilterBar,   $cordovaInAppBrowser,   notificationService,   $localStorage,   $state,   $ionicPopover,   $cordovaSocialSharing,   APP_OPTIONS,   adsService,   modalService,   connectivityMonitor,   $ionicPopup,   $ionicPlatform,   $cordovaToast,   $timeout,   $ionicHistory,   navigationService,   $rootScope,   authService) {

            $scope.$on('$ionicView.beforeEnter', function() {
                /* Initiate Modal Service */
                $scope.modals = modalService.init($scope);
            });

            // setting the application colors on rootScope
            $rootScope.main_theme = 'positive';
            $rootScope.secondary_theme = 'calm';
            $rootScope.titleClass = 'title-right';
            $rootScope.mainSide = 'right';
            $rootScope.secondarySide = 'left';
            $rootScope.backIcon = 'ion-android-arrow-forward';


            // check for new notifications
            notificationService.check();

            $rootScope.$on('$cordovaLocalNotification:click', function (event, notification, state) {
                if(notificationService.get(notification.id)) {
                    navigationService.go('app.notification', {id: notification.id}, 'right');
                }
            });

            authService.checkTokenExpiry();

            $scope.keyword  = null;
            $scope.category = null;
            $scope.location = null;
            $scope.app_title = APP_OPTIONS.app_title;

            /*
             * Checks whether the connection is available or not
             */
            $scope.checkConnection = function() {
                connectivityMonitor.setScope($scope);
                if(connectivityMonitor.isOffline()) {
                    $scope.adss.isLoading = false;
                    return connectivityMonitor.showPopup();
                }
            };

            /*
             * Function to be called when Network enabled
             */
            $scope.onNetworkAvailable = function() {
                $scope.adss.load().then(function() {
                    $scope.adss.isLoading = false;
                });

                adsService.loadSettings().then(function(settings){
                      if (settings.APP__ENABLE_SLIDER === 'YES') {
                            $scope.hasSlider = true;
                            $scope.initializeSlider();
                      }
                });
            };

            /* Resets all the filter parameters */
            $scope.resetFilters = function() {
                $scope.category = {};
                $scope.location = {};
                $scope.adsType = null;
                $scope.adss.load().then(function() {
                    $scope.adss.isLoading = false;
                });
            };

            /* Initiate ads Service */
            $scope.adss = adsService;

            /* load Initial Data */
            $scope.adss.load().then(function() {
                $scope.adss.isLoading = false;
            });
            adsService.loadSettings().then(function(settings){
                 if (settings.APP__ENABLE_SLIDER === 'YES') {
                      $scope.hasSlider = true;
                      $scope.initializeSlider();
                 }
            });

            $scope.initializeSlider = function() {
                $scope.isLoadingSlider = true;
                adsService.loadSlider().then(function(slides) {
                      $scope.isLoadingSlider = false;
                      $scope.slides = slides;
                });
            };

            /* function to be called for refresh */
            $scope.refresh = function() {
                $scope.adss.refresh().then(function() {
                    $scope.$broadcast('scroll.refreshComplete');
                });
            };

            /* function to be called on pagination */
            $scope.loadMore = function() {
                if($scope.adss.isLoadingMore || !$scope.adss.hasMore) {
                    return false;
                }
                $scope.adss.nextPage().then(function(){
                    $scope.$broadcast('scroll.infiniteScrollComplete');
                });
            };

            /*---------- Initializing Filter Bar  ------------*/
            $scope.showFilterBar = function () {
                $ionicFilterBar.show({
                    externalScope : $scope,
                    FunctionToBeCalledOnChange : 'changed',
                    keyboardShowDelay : 300,
                    cancelText: 'بی خیال'
                });
            };
            $scope.changed = function(value) {
                $scope.keyword = value;
            };

            /*-- set a location --*/
            $scope.setLocation = function(location) {
                console.log(location);
                $scope.location = location;
            };
            /*-- set a category --*/
            $scope.setCategory = function(category) {
                $scope.category = category;
            };
            /*-- Reset Location --*/
            $scope.resetLocation = function() {
                $scope.location = {};
            };
            /*-- Reset Category --*/
            $scope.resetCategory = function() {
                $scope.category = {};
            };
            $scope.setSpecificCategory = function(category) {
            };
            $scope.setSpecificSubCategory = function(subcategory) {
            };
            $scope.setSpecificSubCategorySubsidiary = function(subsidiary) {
            };

            /*---------------------- Share ------------------------*/
            /*
             * Brings up the share action sheet with cordovaSocialSharing Plugin
             */
            $scope.share = function(ads) {
                var message = 'آگهی ' + ads.ADS_TITLE + ' در ' + APP_OPTIONS.app_title + '\n';

                $cordovaSocialSharing.share(message, null, null, ads.link_to_ads).then(function(result) {

                });
            };


            /*---------------------- POPOVERS ------------------------*/
            $ionicPopover.fromTemplateUrl('templates/popovers/select_ads_type.html', {
                scope: $scope
            }).then(function(popover) {
                $scope.adsTypePopover = popover;
            });

            /*
             * Shows the popover that contains the types of ads
             */
            $scope.showAdsTypes = function(event) {
                if(connectivityMonitor.isOffline()) {
                    return connectivityMonitor.showPopup();
                }

                $scope.adsTypePopover.show(event);
            };

            /*
             * function to be called when clicking on an ads type in popover
             */
            $scope.setAdsType = function(type) {
                $scope.adsType = type;
                $scope.adsTypePopover.hide();
            };

            /*---------------- WATCH FILTER INPUTS  ------------------*/
            // Watch Locations
            $scope.$watch('location', function(newValue, oldValue) {
                if(newValue === oldValue){
                    return false;
                }
                $scope.adss.params.location = newValue.hasOwnProperty('ID') ? newValue.ID : null;
                $scope.adss.load().then(function() {
                    $scope.adss.isLoading = false;
                });
            });

            // Watch Categories
            $scope.$watch('category', function(newValue, oldValue) {
                if(newValue === oldValue){
                    return false;
                }
                $scope.adss.params.category = newValue.hasOwnProperty('ID') ? newValue.ID : null;
                $scope.adss.load().then(function() {
                    $scope.adss.isLoading = false;
                });
            });

            // Watch adsType
            $scope.$watch('adsType', function(newValue, oldValue) {
                if(newValue === oldValue){
                    return false;
                }
                $scope.adss.params.type = newValue;
                $scope.adss.load().then(function() {
                    $scope.adss.isLoading = false;
                });
            });

            // watch keyword
            $scope.$watch('keyword', function(newValue, oldValue) {
                if(newValue === oldValue){
                    return false;
                }
                $scope.adss.params.keyword = newValue;
                $scope.adss.load().then(function() {
                    $scope.adss.isLoading = false;
                });
            });

            /*
             * Function that triggers when clicking on floating button
             */
            $scope.floatingButtonClicked = function() {
                navigationService.go('app.add-ads');
            };

           /**
            * Handles Click event on main slider slides
            * @param banner
            * @returns {boolean}
            */
            $scope.slideClicked = function(banner) {
                if (banner.link_url == "") {
                    return false;
                }
                var options = { location: 'yes', clearcache: 'yes', toolbar: 'no'};
                $cordovaInAppBrowser.open(banner.link_url, '_system', options)
                    .then(function(event) { /* success*/ })
                    .catch(function(event) { /* error*/ });
            };

            /*
             * Customize the clicking of hardware back button
             */
            var backButton = 0;
            $ionicPlatform.registerBackButtonAction(function() {
                var state = $state.current.name;

                if(state == 'app.list') {
                    if (backButton === 0) {
                        backButton = 1;
                        $cordovaToast.showShortBottom('برای خروج از برنامه یک بار دیگر کلید برگشت را بفشارید');
                        $timeout(function () {
                            backButton = 0;
                        }, 2000);
                    } else {
                        navigator.app.exitApp();
                    }
                } else if (state == 'app.add-ads') {
                    // do nothing
                    // return $scope.backButtonClicked();
                    navigationService.go('app.list', null, 'right');
                } else if (state === 'app.favourites') {
                    navigationService.go('app.list', null, 'right');
                } else if (state === 'app.my-ads') {
                    navigationService.go('app.profile', null, 'right');
                } else if (state === 'app.profile') {
                    navigationService.go('app.list', null, 'right');
                } else if (state === 'app.auth') {
                    navigationService.go('app.list', null, 'right');
                } else if (state === 'app.notification') {
                    navigationService.go('app.list', null, 'right');
                } else if (state === 'app.edit') {
                    navigationService.go('app.my-ads', null, 'right');
                }else {
                    navigationService.goBack();
                }
            }, 100);

            $ionicPlatform.ready(function () {
                $scope.checkConnection();
            });
        }])

    /*----------------------------------------------------------------------------------***
     |
     |                         Ads Detail Controller
     |
     ***--------------------------------------------------------------------------------***/
    .controller('detailsController', ['$scope', '$stateParams', '$cordovaSocialSharing', '$timeout', '$ionicPopup', 'adsService', 'adsFactory', 'APP_OPTIONS', '$rootScope', 'NgMap', 'authService',
        function( $scope,   $stateParams,   $cordovaSocialSharing,   $timeout,   $ionicPopup,   adsService,   adsFactory,   APP_OPTIONS,   $rootScope, NgMap, authService)
        {
            var adsId = $stateParams.id;
            $scope.formData = {};

            $rootScope.isTransparent = true;
            $scope.showMessage = false;
            $scope.message = null;
            $scope.googleMapsUrl = null;
            $scope.hasMap = false;

            adsService.loadSettings().then(function(settings) {
                $scope.googleMapsUrl = APP_OPTIONS.googleMapUrl + settings.GOOGLE_MAP_API_KEY;
                if (settings.APP__ENABLE_MAP === 'YES') {
                    $scope.loadMap = true;
                    $scope.hasMap = true;
                }
            });

            $scope.adss = adsService;
            adsService.findWithId(adsId).then(function(ads) {
                $scope.ads = ads;
                $scope.images = adsService.images($scope.ads.image);
                $scope.isFavourited = adsService.isFavourited($scope.ads.ID);
                if (ads.LONGITUDE && ads.LATITUDE) {
                    $scope.hasMap = true;
                }

                adsService.loadCustomValues($scope.ads).then(function(custom_fields) {
                  //console.log(custom_fields);
                });

                $scope.initializeMap();
            });

            /*
             * Brings up the share action sheet with cordovaSocialSharing Plugin
             */
            $scope.share = function() {

                if($scope.adss.isLoading) { return showMessage('لطفا منتظر بمانید', 1000); }

                var message = 'آگهی ' + $scope.ads.ADS_TITLE + ' در ' + APP_OPTIONS.app_title + '\n';

                $cordovaSocialSharing.share(message, null, null, $scope.ads.link_to_ads).then(function(result) {

                });
            };

            /*
             * Toggles the ads in favourites list
             */
            $scope.toggleFavourite = function() {

                if($scope.adss.isLoading) { return showMessage('لطفا منتظر بمانید', 1000); }

                $scope.isFavourited = adsService.toggleFavourite($scope.ads);
                if($scope.isFavourited) {
                    showMessage('این آگهی به لیست پسندیده های شما اضافه شد');
                } else {
                    showMessage('این آگهی از لیست پسندیده های شما حذف شد');
                }
            };

            /*
             * Brings up sms app for sending sms to ads owner with cordovaSocialSharing Plugin
             */
            $scope.sendSms = function() {

                if($scope.adss.isLoading) { return showMessage('لطفا منتظر بمانید', 1000); }

                if(! hasPhoneNumber()) {
                    showMessage('صاحب آگهی تمایلی به برقراری ارتباط از طریق تماس تلفنی و پیامک ندارد. لطفا از طریق ایمیل اقدام نمایید');
                    return false;
                }

                $cordovaSocialSharing.shareViaSMS('', $scope.ads.ADS_OWNER_PHONE).then(function(result) {

                });
            };

            /*
             * Shows dialer to making a call with ads owner
             */
            $scope.makeCall = function() {

                if($scope.adss.isLoading) { return showMessage('لطفا منتظر بمانید', 1000); }

                if(! hasPhoneNumber()) {
                    showMessage('صاحب آگهی تمایلی به برقراری ارتباط از طریق تماس تلفنی و پیامک ندارد. لطفا از طریق ایمیل اقدام نمایید');
                    return false;
                }

                document.location.href = 'tel:' + $scope.ads.ADS_OWNER_PHONE;
            };

            /*
             * Shows the email Popup
             */
            $scope.showEmailPopup = function() {

                if($scope.adss.isLoading) { return showMessage('لطفا منتظر بمانید', 1000); }

                $scope.emailPopup = $ionicPopup.show({
                    templateUrl: 'templates/popups/send_email.html',
                    cssClass: 'no-header-popup loading-popup has-custom-header',
                    scope: $scope
                });
            };

            /*
             * Shows the email Popup
             */
            $scope.showReportPopup = function() {
                if ($scope.adss.isLoading) { return showMessage('لطفا منتظر بمانید', 1000); }

                $scope.reportPopup = $ionicPopup.show({
                    templateUrl: 'templates/popups/report.html',
                    cssClass: 'no-header-popup loading-popup has-custom-header',
                    scope: $scope
                });
            };

            /*
             * Handles the sending report
             */
            $scope.sendReport = function(form) {
                if(form.$invalid || $scope.isSendingReport) {
                    return false;
                }
                $scope.isSendingReport = true;
                adsService.sendReport($scope.ads.ID, $scope.formData.report_body, authService.token).then(function(result) {
                    if(result.status) {
                        $scope.formData = {};
                        closeReportPopup('گزارش شما با موفقیت ارسال گردید');
                    } else {
                        closeReportPopup(result.errors);
                    }
                }, function(error) {
                    closeReportPopup('مشکلی در ارسال  گزارش به وجود آمده است. لطفا مجددا تلاش نمایید');
                });

                var closeReportPopup = function(message) {
                    $scope.isSendingReport = false;
                    showMessage(message);
                    $scope.reportPopup.close();
                };
            };

            /*
             * Handles the sending email to ads owner
             */
            $scope.sendEmail = function(form) {

                if(form.$invalid || $scope.isSendingEmail) {
                    return false;
                }

                $scope.isSendingEmail = true;
                var subject = APP_OPTIONS.app_title + ' - ' + $scope.ads.ADS_TITLE;

                adsFactory.sendEmail($scope.formData.email, $scope.ads.ADS_OWNER_EMAIL, $scope.formData.text, subject)
                    .then(function(result) {
                        if(result.status) {
                            $scope.formData = {};
                            closeEmailPopup('پیام شما با موفقیت برای صاحب آگهی ارسال شد');
                        } else {
                            closeEmailPopup(result.errors);
                        }
                    }, function(err) {
                        closeEmailPopup('مشکلی در ارسال  پیام شما به وجود آمده است. لطفا مجددا تلاش نمایید');
                    });

                var closeEmailPopup = function(message) {
                    $scope.isSendingEmail = false;
                    showMessage(message);
                    $scope.emailPopup.close();
                };
            };

            $scope.goToLink = function(link) {
                window.open(link, '_system');
            };


            /*
             * Checks whether the ads owner has a phone number or not
             */
            var hasPhoneNumber = function() {
                if($scope.ads.ADS_OWNER_PHONE && typeof $scope.ads.ADS_OWNER_PHONE != 'undefined' && $scope.ads.ADS_OWNER_PHONE !== null) {
                    return true;
                }

                return false;
            };

            /*
             * Shows phone number message for the given second
             */
            var showMessage = function(message, delay) {
                delay = delay || 3000;

                $scope.message = message;
                $scope.showMessage = true;

                $timeout(function() {
                    $scope.showMessage = false;
                }, delay);
            };

            $scope.initializeMap = function() {
                    NgMap.getMap("detailMap").then(function(map) {
                            $scope.mapInstance = map;
                            var default_location = new google.maps.LatLng($scope.ads.LATITUDE, $scope.ads.LONGITUDE);
                            $scope.mapInstance.setCenter(default_location);
                            marker = new google.maps.Marker({
                                    map: $scope.mapInstance,
                                    draggable:true,
                                    animation: google.maps.Animation.DROP,
                                    position: default_location
                            });
                    });
            };

        }])

    /*----------------------------------------------------------------------------------***
     |
     |                         Favourites Controller
     |
     ***--------------------------------------------------------------------------------***/
    .controller('favouritesController', ['$scope', '$localStorage', 'adsService', function($scope, $localStorage, adsService) {
        $scope.$on('$ionicView.beforeEnter', function() {
            $scope.favourites = $localStorage.favourites;
        });

        $scope.adsService = adsService;
    }]);
