angular.module('koClassified.factories.adsFactory', [])

  .factory('adsFactory', ['$http', '$q', '$cordovaFileTransfer', 'APP_OPTIONS',
                function ( $http,   $q,   $cordovaFileTransfer,   APP_OPTIONS)
  {
      var factory = {};

      /*
       * Returns the list of ads with defined parameters
       *
       * @params Object : object of filter parameters
       */
      factory.getAds = function (params) {
          var defered = $q.defer();
          var data    = params || {};

          $http({
              method: "get",
              url   : APP_OPTIONS.api_base,
              params: {
                action: "get",
                data  : data
              }
          }).success(function (data) {
              defered.resolve(data);
          }).error(function () {
              defered.reject('Error Accoured');
          });

          return defered.promise;
      };

      /**
       * Loads the ads with the given id
       * @param id
       * @returns {*}
       */
      factory.findById = function(id) {
          var defered = $q.defer();

          $http({
              method: "get",
              url   : APP_OPTIONS.api_base + '/by-id',
              params: {
                action: "get",
                data  : { id: id }
              }
          }).success(function (data) {
              defered.resolve(data);
          }).error(function () {
              defered.reject('Error Accoured');
          });

          return defered.promise;
      };

    /**
     * Loads the ads with the given id
     * @param id
     * @returns {*}
     */
    factory.findByIdForEdit = function(id) {
        var defered = $q.defer();

        $http({
            method: "get",
            url   : APP_OPTIONS.api_base + '/find-for-edit',
            params: {
                action: "get",
                data  : { id: id }
            }
        }).success(function (data) {
            defered.resolve(data);
        }).error(function () {
            defered.reject('Error Accoured');
        });

        return defered.promise;
    };

      factory.allAdsOfUser = function(token) {
          var defered = $q.defer();

          var data = JSON.stringify({ token: token });
          var config = {headers : {
            'Content-Type': 'application/json'
          }};
          var send = $http.post(APP_OPTIONS.api_base + '/user-adss', data, config);
          send.success(function(result) {
              defered.resolve(result);
          });
          send.error(function (error) {
              defered.reject(error);
          });

          return defered.promise;
      };

      /*
       * Returns the list of all locations
       */
      factory.getLocations = function () {
        var defered = $q.defer();
        $http.get(APP_OPTIONS.api_base + '/locations')
          .success(function (data) {
            defered.resolve(data);
          })
          .error(function () {
            defered.reject('Error Accoured');
          });

        return defered.promise;
      };

      /*
       * Returns the list of all categories
       */
      factory.getCategories = function () {
        var defered = $q.defer();

        $http.get(APP_OPTIONS.api_base + '/categories')
          .success(function (data) {
            defered.resolve(data);
          })
          .error(function () {
            defered.reject('Error Accoured');
          });

        return defered.promise;
      };

      /*
      * Uploads the given image to server
      */
      factory.upload = function(imageFileURI) {
          var uploadUrl = APP_OPTIONS.api_base + '/upload';

          var options = {
              fileKey: "file",
              fileName: imageFileURI.split("/").pop(),
              chunkedMode: false,
              mimeType: "image/jpg"
          };

          /**
          * Deleting query string from image name before uploading (for image library)
          */
          var mark_index = options.fileName.indexOf('?');
          options.fileName = options.fileName.substring(0, mark_index != -1 ? mark_index : options.fileName.length);

          var defered = $q.defer();

              $cordovaFileTransfer.upload(uploadUrl, imageFileURI, options).then(function(result) {
                    defered.resolve(result);
              }, function(err) {
                    defered.reject(err);
              }, function (progress) {
                  console.log('PROGRESS FOR = ' +(progress.loaded / progress.total) * 100);
              });

          return defered.promise;
      };

      /*
       * Sends the addAds form data to server
       */
      factory.postAds = function (params) {
          var defered = $q.defer();

          data = JSON.stringify({ data: params });
          var config = {headers : {
            'Content-Type': 'application/json'
          }};
          var send = $http.post(APP_OPTIONS.api_base + '/add', data, config);
          send.success(function(result) {
            defered.resolve(result);
          });
          send.error(function (error) {
            defered.reject(error);
          });

          return defered.promise;
      };

      /*
       * Sends the addAds form data to server
       */
      factory.updateAds = function (params) {
          var defered = $q.defer();

          data = JSON.stringify({ data: params });
          var config = {headers : {
            'Content-Type': 'application/json'
          }};
          var send = $http.post(APP_OPTIONS.api_base + '/update', data, config);
          send.success(function(result) {
            defered.resolve(result);
          });
          send.error(function (error) {
            defered.reject(error);
          });

          return defered.promise;
      };

      /*
      * Sends data to server for sending email
      */
      factory.sendEmail = function(from, to, text, subject) {
          var defered = $q.defer();

          var data = {
              from: from,
              to: to,
              text: text,
              subject: subject
          };

          $http({
              method: "post",
              url   : APP_OPTIONS.api_base + '/send-email',
              params: {data: data}
          }).success(function (result) {
                defered.resolve(result);
          }).error(function(error){
                defered.reject('rejected in factory');
          });

          return defered.promise;
      };

      /**
       * Loads Site Settings
       */
      factory.getSettings = function () {
          var defered = $q.defer();
          var public_key = APP_OPTIONS.public_key;
          var private_key = APP_OPTIONS.private_key;

          $http({
              method: "get",
              url   : APP_OPTIONS.api_base + '/settings',
              params: {
                  key:  CryptoJS.HmacSHA256(public_key, private_key).toString()
              }
              // headers: {
              //     xHash:  CryptoJS.HmacSHA256(public_key, private_key)
              // }
          }).success(function (data) {
              defered.resolve(data);
          }).error(function () {
              defered.reject('Error Accoured');
          });

          return defered.promise;
      };

      /**
       * Loads All Plans
       */
      factory.getPlans = function () {
          var defered = $q.defer();

          $http({
              method: "get",
              url   : APP_OPTIONS.api_base + '/plans',
              params: {}
          }).success(function (data) {
              defered.resolve(data);
          }).error(function () {
              defered.reject('Error Accoured');
          });

          return defered.promise;
      };

      /**
       * Loads Default Plan
       */
      factory.getDefaultPlan = function () {
          var defered = $q.defer();

          $http({
              method: "get",
              url   : APP_OPTIONS.api_base + '/default-plan',
              params: {}
          }).success(function (data) {
              defered.resolve(data);
          }).error(function () {
              defered.reject('Error Accoured');
          });

          return defered.promise;
      };

      /**
       * Increment Current Views of item
       */
      factory.incrementViews = function(ads_id) {
          $http({
              method: "get",
              url   : APP_OPTIONS.api_base + '/increment-item-views',
              params: {
                  ads_id: ads_id
              }
          });
      };

      /**
       * Load Notifications
       */
      factory.loadNotification = function() {

          var defered = $q.defer();

          $http({
              method: "get",
              url   : APP_OPTIONS.api_base + '/notification',
              params: {}
          }).success(function (data) {
              defered.resolve(data);
          }).error(function () {
              defered.reject('Error Accoured');
          });

          return defered.promise;
      };


      factory.getCustomValues = function(ads_id) {
          var defered = $q.defer();
          $http({
              method: "get",
              url   : APP_OPTIONS.api_base + '/custom-values',
              params: {
                ads_id: ads_id
              }
          }).success(function (data) {
              defered.resolve(data);
          }).error(function () {
              defered.reject('Error Accoured');
          });

          return defered.promise;
      };

      factory.getCustomFields = function(cat_id, subcat_id, subsidiary_id) {
          var defered = $q.defer();

          $http({
              method: "get",
              url   : APP_OPTIONS.api_base + '/custom-fields',
              params: {
                  cat_id: cat_id,
                  subcat_id: subcat_id,
                  subsidiary_id: subsidiary_id
              }
          }).success(function (data) {
              defered.resolve(data);
          }).error(function () {
              defered.reject('Error Accoured');
          });

          return defered.promise;
      };

      /**
       * soft deletes an Ads
       * @param item_id
       * @param token
       * @returns {*}
       */
      factory.deleteItem = function(item_id, token) {
          var defered = $q.defer();

          var data = JSON.stringify({ token: token, ads_id: item_id });
          var config = {headers : {
              'Content-Type': 'application/json'
          }};
          var send = $http.post(APP_OPTIONS.api_base + '/delete-item', data, config);
          send.success(function(result) {
              defered.resolve(result);
          });
          send.error(function (error) {
              defered.reject(error);
          });

          return defered.promise;
      };

       /**
       * Returns images for main slider
       * @returns {*}
       */
      factory.getSlides = function() {
          var defered = $q.defer();

          $http({
                  method: "get",
                  url   : APP_OPTIONS.api_base + '/banners',
                  params: {}
          }).success(function (data) {
                  defered.resolve(data);
          }).error(function () {
                  defered.reject('Error Accoured');
          });

          return defered.promise;
      };

      /*
       * Sends the mutate request to server
       */
      factory.mutate = function (params) {
          var defered = $q.defer();

          var data = JSON.stringify({ data: params });

          var config = {headers : {
                  'Content-Type': 'application/json'
              }};
          var send = $http.post(APP_OPTIONS.api_base + '/mutate', data, config);
          send.success(function(result) {
              defered.resolve(result);
          });
          send.error(function (error) {
              defered.reject(error);
          });

          return defered.promise;
      };

      /*
       * Sends the addAds form data to server
       */
      factory.postReport = function (params) {
          var defered = $q.defer();

          data = JSON.stringify({ data: params });

          var config = {headers : {
              'Content-Type': 'application/json'
          }};
          var send = $http.post(APP_OPTIONS.api_base + '/store-report', data, config);
          send.success(function(result) {
              defered.resolve(result);
          });
          send.error(function (error) {
              defered.reject(error);
          });

          return defered.promise;
      };

      return factory;

  }]);
