angular.module('koClassified.services.blog', [])

  .service('blogService', ['$q', '$localStorage', 'lodash', 'blogFactory',
                function (  $q,   $localStorage,   _,        blogFactory) {

    var self = this;

      self.categories = [];
      self.isLoadingCategories = false;
      self.isLoadingMore = false;

    self.reset = function() {
        self.items     = [];
        self.hasMore   = true;
        self.isLoading = false;
        self.params.page = 1;
    };

    self.params = {
        category : null,
        keyword : null,
        page : 1
    };


    /*
     * loads the ads items from Factory
     */
    self.load = function () {
        var defered = $q.defer();
        self.isLoading = true;
        self.params.page = 1;
        self.hasMore = true;

        blogFactory.getPosts(self.params).then(function(data) {
            if (data.length === 0) {
                self.hasMore = false;
            }

            self.items = data;
            //self.isLoading = false;
            defered.resolve();
        });

        return defered.promise;
    };

    /*
    * Load Categories from blogFactory
    */
    self.loadCategories = function () {
        var defered = $q.defer();
        self.isLoadingCategories = true;
        self.categories = blogFactory.getCategories().then(function(categories) {
            self.isLoadingCategories = false;
            self.categories = categories;
            defered.resolve(categories);
        });

        return defered.promise;
    };

    /*
    * Refreshes the list of items
    */
    self.refresh = function () {
        var defered = $q.defer();
            self.reset();
            self.load().then(function() {
                self.isLoading = false;
            });
            defered.resolve();
        return defered.promise;
    };

    /*
    * Loads the data for next page in the ads list
    */
    self.nextPage = function() {
        var defered = $q.defer();
        self.params.page += 1;

        self.isLoadingMore = true;
        blogFactory.getPosts(self.params).then(function(data)
        {
             if(data.length === 0) {
                 self.params.page -= 1;
                 self.hasMore = false;
             }

            self.items = self.items.concat(data);

            self.isLoadingMore = false;
            defered.resolve();
        });

        return defered.promise;
    };


    /*
    * Returns the url to the featured image of the given Item
    */
    self.showFeaturedImage = function(item, remove_cache) {
        remove_cache = remove_cache || false;

        if(!item) {
            return false;
        }

        if (remove_cache) {
            return item.featured_image + '?rand=' + remove_cache;
        }

        return item.featured_image;
    };

    /*
    * Returns the Url of featured image for the specific item
    *
    * @image array|string : the image variable of the desired ads item
    */
    self.images = function (image) {
        try {
          return JSON.parse(image);
        } catch (e) {
          return [image];
        }
    };

    self.isActive = function(item) {
        return item.IS_ACTIVE == 2;
    };

    /*
    * Returns an ads by it's id
    *
    * @id string | integer : id of the desired ads item
    */
    self.findWithId = function (post_id) {
        var defered = $q.defer();
        self.isLoading = false;

        // if already in the loaded list, return it
        var post = _.find(self.items, {'ID': parseInt(post_id)});
        if (post) {
            defered.resolve(post);
        }

        // otherwise load it via http call
        else {
            self.isLoading = true;
            blogFactory.findById(post_id).then(function(result) {
                self.isLoading = false;
                defered.resolve(result);
            }, function(err) {
                self.isLoading = false;
                defered.reject(err);
            });
        }

        return defered.promise;
    };

    /* functions to run on Instantiation */
    self.reset();
  }]);
