angular.module('koClassified.services.notification', [])
    .service('notificationService', ['$q', '$ionicPlatform', '$cordovaLocalNotification', '$localStorage', '$rootScope', '$ionicPopup', '$cordovaFileTransfer', '$cordovaFileOpener2', '$timeout', 'adsFactory', function(
                                      $q,   $ionicPlatform,   $cordovaLocalNotification,   $localStorage,   $rootScope,   $ionicPopup,   $cordovaFileTransfer,   $cordovaFileOpener2,   $timeout,   adsFactory  ) {

        var self = this;

        /*
        * Load and checks for new notifications
        */
        self.check = function() {
            adsFactory.loadNotification().then(function(response) {
                angular.forEach(response.notifications, function(notification, key) {
                    self.add(notification.id, notification.title, notification.text);
                });

                $ionicPlatform.ready(function() {
                    if (device.platform != 'iOS' && device.platform != 'ios') {
                        self.checkForUpdate(response.latest_app_version, response.latest_app_url);
                    }
                });
                
            });
        };

        /*
        * Check Whether the application needs an update or not
        */
        self.checkForUpdate = function(latest_app_version, latest_app_url) {
            $ionicPlatform.ready(function () {
                cordova.getAppVersion(function(current_app_version) {
                    if(parseInt(latest_app_version) > parseInt(current_app_version)) {
                        $rootScope.latest_app_url = latest_app_url;
                        self.showUpdatePopup();
                    }
                });
            });
        };

        /*
        * Shows Popup for updating application
        */
        self.showUpdatePopup = function() {
            $rootScope.updateAppPopup = $ionicPopup.show({
                templateUrl : 'templates/popups/update_application.html',
                scope : $rootScope,
                cssClass : 'no-header-popup loading-popup ' + $rootScope.main_theme
            }, 1000);
        };

        /*
        * Closes the popup of application update
        */
        $rootScope.closeUpdatePopup = function() {
            $rootScope.updateAppPopup.close();
        };

        $rootScope.startUpdate = function() {
            var url = $rootScope.latest_app_url;
            console.log(url);
            var targetPath = cordova.file.externalDataDirectory + url.split("/").pop();

            $rootScope.isDownloadingUpdate = true;
            $cordovaFileTransfer.download(url, targetPath, {}, true).then(function(result) {
                $rootScope.isDownloadingUpdate = false;
                $rootScope.closeUpdatePopup();
                $rootScope.openDownloadedApplication(result.nativeURL);
            }, function(err) {
                $rootScope.isDownloadingUpdate = false;
                console.log(JSON.stringify(err));
            });
        };

        $rootScope.openDownloadedApplication = function(url) {
            $cordovaFileOpener2.open(url, 'application/vnd.android.package-archive').then(function() {
            }, function(err) {
                console.log('file not opened');
                console.log(JSON.stringify(err));
            });
        };


        /*
        * schedule a new notification
        */
        self.add = function(id, title, message)
        {
            $ionicPlatform.ready(function() {
                var options = {
                    id: parseInt(id),
                    title: title,
                    text: message
                    //data : { customProperty: 'custom value'}
                };

                if( ! self.isWatched(parseInt(id)) ) {
                    $cordovaLocalNotification.schedule(options);
                }
                self.addToLocalStorage(options);
            });
        };

        /*
        * Saves the given notification in local storage
        */
        self.addToLocalStorage = function(notification) {
            if( ! $localStorage.notifications ) {
                $localStorage.notifications = [];
            }

            if( ! self.get(notification.id) ) {
                $localStorage.notifications.push(notification);
            }
        };

        /*
         * Returns all available notifications
         */
        self.all = function() {
            return $localStorage.notifications;
        };

        self.makeWatched = function(notification) {
            if(! $localStorage.watchedNotification) {
                $localStorage.watchedNotification = [];
            }

            if( ! self.isWatched(notification.id) ) {
                $localStorage.watchedNotification.push({ id: notification.id });
            }
        };

        /*
        * Returns the notification with the given ID
        */
        self.get = function(id) {
            return _.find($localStorage.notifications, {id: id});
        };

       /*
       * Checks whether the notification with the given ID is already watched or not
       */
        self.isWatched = function(id) {
            if( ! $localStorage.watchedNotification ) {
                $localStorage.watchedNotification = [];
            }

            return !!_.find($localStorage.watchedNotification, {id: id});

        };

       /*
       * Deletes the given notification from local storage
       */
        self.delete = function(notification) {
            _.remove($localStorage.notifications, function(currentObject) {
                return currentObject.id == notification.id;
            });
        };

      self.allWatched = function() {
          return $localStorage.watchedNotification;
      };

    }]);
